'use strict';

var path = require('path');
var mime = require('mime');
var sander = require('sander');
var sourcemap = require('../../utils/sourcemap');



exports['default'] = serveFile;
function serveFile(filepath, request, response) {
	var ext = path.extname(filepath);

	// this might be turn out to be a really bad idea. But let's try it and see
	if (ext === ".js" || ext === ".css") {
		return sander.readFile(filepath).then(function (data) {
			// this takes the auto-generated absolute sourcemap path, and turns
			// it into what you'd get with `gobble build` or `gobble watch`
			var sourcemapComment = sourcemap.getSourcemapComment(path.basename(filepath) + ".map", ext);
			data = data.toString().replace(sourcemap.SOURCEMAP_COMMENT, sourcemapComment);

			response.statusCode = 200;
			response.setHeader("Content-Type", mime.lookup(filepath));

			response.write(data);
			response.end();
		});
	}

	return sander.stat(filepath).then(function (stats) {
		response.statusCode = 200;
		response.setHeader("Content-Type", mime.lookup(filepath));
		response.setHeader("Content-Length", stats.size);

		sander.createReadStream(filepath).pipe(response);
	});
}
//# sourceMappingURL=serveFile.js.map
